@@ -1,7 +1,7 @@
 /*
  * nametype - associate names with values
  *
- * Copyright (C) 1999  Landon Curt Noll
+ * Copyright (C) 1999,2014  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -9,7 +9,7 @@
  *
  * Calc is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU Lesser General
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General
  * Public License for more details.
  *
  * A copy of version 2.1 of the GNU Lesser General Public License is
@@ -17,29 +17,22 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.1 $
- * @(#) $Id: nametype.h,v 30.1 2007/03/16 11:09:46 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/nametype.h,v $
+ * Under source code control:   1997/03/08 13:44:55
+ * File existed as early as:    1997
  *
- * Under source code control:	1997/03/08 13:44:55
- * File existed as early as:	1997
- *
- * chongo <was here> /\oo/\	http://www.isthe.com/chongo/
- * Share and enjoy!  :-)	http://www.isthe.com/chongo/tech/comp/calc/
+ * chongo <was here> /\oo/\     http://www.isthe.com/chongo/
+ * Share and enjoy!  :-)        http://www.isthe.com/chongo/tech/comp/calc/
  */
 
-
-#if !defined(__NAMETYPE_H__)
-#define __NAMETYPE_H__
-
+#if !defined(INCLUDE_NAMETYPE_H)
+#  define INCLUDE_NAMETYPE_H
 
 /*
  * Configuration parameter name and type.
  */
 typedef struct {
-	char *name;	/* name of configuration string */
-	long type;	/* type for configuration */
+    char *name; /* name of configuration string */
+    long type;  /* type for configuration */
 } NAMETYPE;
 
-
-#endif /* !__NAMETYPE_H__ */
+#endif /* !INCLUDE_NAMETYPE_H */
